/*
 * $Id: platform.h,v 1.1 2008/07/15 22:48:16 nbrk Exp $
 */
/*-
 * Copyright (c) 2005, Kohsuke Ohtani
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of any co-contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _OFFSETS_H
#define _OFFSETS_H

#define DEBUG_BOOT

#define PAGE_OFFSET	0x00000000

#define BOOT_INFO	0x10030000
#define BOOT_INFO_SIZE	0x00000800
/* #define BOOT_STACK	(0x11fbfffc - BOOT_INFO_SIZE) */
#define BOOT_STACK	0x11fc0000 - BOOT_INFO_SIZE
#define ARCHIVE_START	0x08002000	/* XXX */

#define BOOT_PARAMS	0x11fc0000

#ifndef __ASSEMBLY__

/*
 * Page mapping
 */
#define phys_to_virt(p_addr)	(void *)((u_long)(p_addr) + PAGE_OFFSET)
#define virt_to_phys(v_addr)	(void *)((u_long)(v_addr) - PAGE_OFFSET)

#if defined(DEBUG)

/* XXX probably should be defined somewhere else to share with MI code */
#define DEBUG_USART_THR	0xffe0101c	/* transmitter holding register */
#define DEBUG_USART_CSR	0xffe01014	/* channel status register */
#define  USART_CSR_TXRDY	0x02

/*
 * Put one character over USART1, which is an onboard RS232.
 */
static __inline void
putc(int c)
{
	/* poll TXRDY */
	while ((*(volatile uint32_t *)(DEBUG_USART_CSR) & USART_CSR_TXRDY) == 0)
		;

	*(volatile uint32_t *)DEBUG_USART_THR = c;
}
#else
#define putc(c)
#endif
extern void setup_bootinfo(struct boot_info **);

#endif /* !__ASSEMBLY__ */
#endif /* _OFFSETS_H */
